@@ -17,12 +17,12 @@ L.MapListSync = L.Class.extend({
         L.Util.setOptions(this, options);
 
         this.selectorOnce = this.__initSelectorOnce(); // TODO: rename this and refactor
-        this._dtcontainer = this.dt.fnSettings().nTableWrapper;
+        //this._dtcontainer = this.dt.fnSettings().nTableWrapper;
 
-        this.dt.fnSettings()['aoRowCreatedCallback'].push({
-            fn: this._onRowCreated.bind(this),
-            sName: 'user',
-        });
+        // this.dt.fnSettings()['aoRowCreatedCallback'].push({
+        //     fn: this._onRowCreated.bind(this),
+        //     sName: 'user',
+        // });
 
         this.layer.on('mouseintent', this._onObjectOver.bind(this));
 
@@ -33,8 +33,7 @@ L.MapListSync = L.Class.extend({
             this.options.filter.submitbutton.click(this._onFormSubmit.bind(this));
             this.options.filter.resetbutton.click(this._onFormReset.bind(this));
         }
-
-        $(this.dt.fnSettings().oInstance).on('filter', this._onListFilter.bind(this));
+        $(this.dt.settings().oInstance).on('filter', this._onListFilter.bind(this));
     },
 
     _onListFilter: function () {
@@ -64,21 +63,21 @@ L.MapListSync = L.Class.extend({
 
     _onFormReset: function (e) {
         this._formClear($(this.options.filter.form)); // clear all fields
-        this._formSetBounds(); // re-fill current bbox
         this._reloadList();
-        this.layer.updateFromPks(Object.keys(this.layer._objects));
+        this._formSetBounds(); // re-fill current bbox
+        //this.layer.updateFromPks(Object.keys(this.layer._objects));
     },
 
     _onObjectOver: function (e) {
         var self = this;
         var search_pk = e.layer.properties.pk;
-        JQDataTable.goToPage(this.dt,
-            function pk_equals(row) {
-                return row[0] === search_pk;
-            }, function($row) {
-                self.selectorOnce.select(search_pk, $row);
-            }
-        );
+        // JQDataTable.goToPage(this.dt,
+        //     function pk_equals(row) {
+        //         return row[0] === search_pk;
+        //     }, function($row) {
+        //         self.selectorOnce.select(search_pk, $row);
+        //     }
+        // );
     },
 
     _onRowCreated: function(nRow, aData, iDataIndex ) {
@@ -103,20 +102,44 @@ L.MapListSync = L.Class.extend({
     },
 
     _reloadList: function (refreshLayer) {
+        var formData = new FormData(document.querySelector('#mainfilter'));
+        var filter = false;
+
+        for (var value of Array.from(formData)) {
+            if (value[0] !== 'bbox') {
+                if (value[1] !== '') {
+                    filter = true;
+                }
+            }
+        }
+        if (filter) {
+            $('#filters-btn').removeClass('btn-info');
+            $('#filters-btn').addClass('btn-warning');
+        }
+        else {
+            $('#filters-btn').removeClass('btn-warning');
+            $('#filters-btn').addClass('btn-info');
+        }
+
+
+        this.dt.ajax.url($('#mainfilter').attr('action') + '?' + $('#mainfilter').serialize()).load();
+
+
         if (this._loading)
             return;
         this._loading = true;
+
         var spinner = new Spinner().spin(this._dtcontainer);
 
         // on JSON load, return the json used by dataTable
         // Update also the map given the layer's pk
         var self = this;
         var extract_data_and_pks = function(data, type, callback_args) {
+
             callback_args.map_obj_pk = data.map_obj_pk;
             return data.aaData;
         };
         var on_data_loaded = function (oSettings, callback_args) {
-
             var nbrecords = self.dt.fnSettings().fnRecordsTotal();
             var nbonmap = Object.keys(self.layer.getCurrentLayers()).length;
 
@@ -148,11 +171,21 @@ L.MapListSync = L.Class.extend({
             self._loading = false;  // loading done.
         };
 
+        // get filtered pks
+        $.get($('#mainfilter').attr('action').replace('.datatables', '/filter_infos.json'),
+            $('#mainfilter').serialize(),
+            function(data) {
+                $('#nbresults').text(data.count);
+                this.layer.updateFromPks(data.pk_list);
+                spinner.stop();
+                self._loading = false;  // loading done.
+            }.bind(this));
+
         var url = this.options.url;
         if (this.options.filter) {
             url = this.options.filter.form.attr("action") + '?' + this.options.filter.form.serialize();
         }
-        this.dt.fnReloadAjax(url, extract_data_and_pks, on_data_loaded);
+        //this.dt.fnReloadAjax(url, extract_data_and_pks, on_data_loaded);
         return false;
     },
 
@@ -164,9 +197,17 @@ L.MapListSync = L.Class.extend({
             console.warn("Map view not set, cannot get bounds.");
             return;
         }
+        var bounds = this.map.getBounds();
+        // get map bound coordinates, keep them in max real values
+        var min_lat = Math.max(bounds._southWest.lat, -90);
+        var max_lat = Math.min(bounds._northEast.lat, 90);
+        var min_lon = Math.max(bounds._southWest.lng, -180);
+        var max_lon = Math.min(bounds._northEast.lng, 180);
+
         var bounds = this.map.getBounds(),
             rect = new L.Rectangle([bounds._northEast, bounds._southWest]);
         this.options.filter.bboxfield.val(L.Util.getWKT(rect));
+        //this.options.filter.bboxfield.val(`${min_lon},${min_lat},${max_lon},${max_lat}`);
     },
 
     _formClear: function ($form) {
